import { useMemo } from 'react';
import { PropTypes } from 'prop-types';
import useList from '../../utils/List';
import WorkContractContext from '../../contexts/WorkContractContext';
import AvailabilityStakes from './AvailabilityStakes';
import WorkRequests from './WorkRequests';

function WorkContract({
  workContract,
  showAvailabilityActions,
  showAvailabilityAmount,
  onlyShowAvailable,
  title,
  verb,
  showRequestWork,
}) {
  const [availabilityStakes, dispatchAvailabilityStake] = useList();
  const workContractProviderValue = useMemo(() => ({
    workContract, availabilityStakes, dispatchAvailabilityStake,
  }), [workContract, availabilityStakes, dispatchAvailabilityStake]);
  return (
    <WorkContractContext.Provider value={workContractProviderValue}>
      <h2>{title}</h2>
      <AvailabilityStakes
        showActions={showAvailabilityActions}
        showAmount={showAvailabilityAmount}
        onlyShowAvailable={onlyShowAvailable}
      />
      <WorkRequests verb={verb} showRequestWork={showRequestWork} />
    </WorkContractContext.Provider>
  );
}

WorkContract.propTypes = {
  workContract: PropTypes.any.isRequired, // eslint-disable-line react/forbid-prop-types
  showRequestWork: PropTypes.bool,
  title: PropTypes.string.isRequired,
  verb: PropTypes.string.isRequired,
  showAvailabilityActions: PropTypes.bool,
  showAvailabilityAmount: PropTypes.bool,
  onlyShowAvailable: PropTypes.bool,
};

WorkContract.defaultProps = {
  showRequestWork: false,
  showAvailabilityActions: true,
  showAvailabilityAmount: true,
  onlyShowAvailable: false,
};

export default WorkContract;
