const axios = require('axios');
const { readFileSync } = require('fs');
const https = require('https');
const objectHash = require('object-hash');
const { recoverPersonalSignature } = require('@metamask/eth-sig-util');

require('dotenv').config();

const apiUrl = process.env.API_URL;
const caPath = process.env.CA_PATH;

const readFromApi = async (hash) => {
  const options = {};
  if (caPath) {
    options.httpsAgent = new https.Agent({
      ca: readFileSync(caPath),
    });
  }
  const { data: { author, content, signature } } = await axios.get(`${apiUrl}/read/${hash}`, options);

  // Verify hash
  const derivedHash = objectHash({ author, content, signature });
  if (derivedHash !== hash) {
    throw new Error('hash mismatch');
  }

  // Verify signature
  const account = recoverPersonalSignature({ data: content, signature });
  if (account !== author) {
    throw new Error('author does not match signature');
  }
  return { author, content, signature };
};

module.exports = readFromApi;
